==> gargoyle-free_2022.1+dfsg.orig.tar.xz: garglk-2022.1/terps/alan3/sysdep.h <==
/*----------------------------------------------------------------------*\

  sysdep.h

  System dependencies file for Alan Adventure Language system

  N.B. The test for symbols used here should really be of three types
  - processor name (like PC, x86, ...)
  - os name (WIN32, Cygwin, MSYS2...)
  - compiler name and version (DJGPP, CYGWIN, GCC271, THINK-C, ...)

  The set symbols should indicate if a feature is on or off like the GNU
  AUTOCONFIG package does.

  This is not completely done yet!

\*----------------------------------------------------------------------*/
#ifndef _SYSDEP_H_
#define _SYSDEP_H_


/* Place definitions of OS and compiler here if necessary */
#ifndef __unix__
#ifdef unix
#define __unix__
#endif
#endif

#ifdef __APPLE__
// At least GCC 3.x does define this for Darwin
#define __macosx__
#define __unix__
#endif

#ifdef __MINGW32__
#define __windows__
#endif

#ifdef __CYGWIN32__
#define __cygwin__
#endif

#ifdef HAVE_WINGLK
#define HAVE_GLK
#endif

#ifdef HAVE_GARGLK
#define HAVE_GLK
#endif


/*----------------------------------------------------------------------

  Below follows OS and compiler dependent settings. They should not be
  changed except for introducing new sections when porting to new
  environments.

 */

/************/
/* Includes */
/************/

#include <stdio.h>
#include <ctype.h>
#include <unistd.h>


#ifdef __STDC__
#define _PROTOTYPES_
#include <stdlib.h>
#include <string.h>
#endif


#ifdef __mac__
#define _PROTOTYPES_
#include <stdlib.h>
#include <string.h>
#endif

/***********************/
/* ISO character sets? */
/***********************/

/* Common case first */
#define ISO 1
#define NATIVECHARSET 0

#ifdef HAVE_GLK
#undef ISO
#define ISO 1
#undef NATIVECHARSET
#define NATIVECHARSET 0
#else	/* Glk is ISO, no matter what the OS */

#ifdef __win__
#undef ISO
#define ISO 1
#undef NATIVECHARSET
#define NATIVECHARSET 2
#endif

/* Old Macs uses other CHARSET, Mac OS X uses ISO */
#ifdef __mac__
#undef ISO
#define ISO 0
#undef NATIVECHARSET
#define NATIVECHARSET 1
#endif

#endif

/**************************/
/* Strings for file modes */
/**************************/
#define READ_MODE "rb"
#define WRITE_MODE "wb"


/****************************/
/* Allocates cleared bytes? */
/****************************/

#ifdef __CYGWIN__
#define NOTCALLOC
#endif

#ifdef __MINGW32__
#define NOTCALLOC
#endif

#ifdef __unix__
#define NOTCALLOC
#endif


/****************/
/* Have termio? */
/****************/

#ifdef HAVE_GLK
#  undef HAVE_TERMIO   /* don't need TERMIO */
#else
#  ifdef __CYGWIN__
#    define HAVE_TERMIO
#  endif
#  ifdef __unix__
#    define HAVE_TERMIO
#  endif
#endif

/*******************************/
/* Is ANSI control available? */
/*******************************/

#ifdef HAVE_GLK
#  undef HAVE_ANSI /* don't need ANSI */
#else
#  ifdef __CYGWIN__
#    define HAVE_ANSI
#  endif
#endif

/******************************/
/* Use the READLINE function? */
/******************************/
#define USE_READLINE
#ifdef SOME_PLATFORM_WHICH_CANT_USE_READLINE
#  undef USE_READLINE
#endif

/* Special cases and definition overrides */
#ifdef __unix__
#define MULTI
#endif


/* Native character functions */
extern int isSpace(unsigned int c);      /* IN - Native character to test */
extern int isLower(unsigned int c);      /* IN - Native character to test */
extern int isUpper(unsigned int c);      /* IN - Native character to test */
extern int isLetter(unsigned int c);     /* IN - Native character to test */
extern int toLower(unsigned int c);      /* IN - Native character to convert */
extern int toUpper(unsigned int c);      /* IN - Native character to convert */
extern char *strlow(char str[]); /* INOUT - Native string to convert */
extern char *strupp(char str[]); /* INOUT - Native string to convert */

/* ISO character functions */
extern int isISOLetter(int c);  /* IN - ISO character to test */
extern char IsoToLowerCase(int c); /* IN - ISO character to convert */
extern char IsoToUpperCase(int c); /* IN - ISO character to convert */
extern char *stringLower(char str[]); /* INOUT - ISO string to convert */
extern char *stringUpper(char str[]); /* INOUT - ISO string to convert */
extern int compareStrings(char str1[], char str2[]); /* Case-insensitive compare */

/* ISO string conversion functions */
extern void toIso(char copy[],  /* OUT - Mapped string */
          char original[], /* IN - string to convert */
          int charset);	/* IN - The current character set */

extern void fromIso(char copy[], /* OUT - Mapped string */
            char original[]); /* IN - string to convert */

extern void toNative(char copy[], /* OUT - Mapped string */
             char original[], /* IN - string to convert */
             int charset); /* IN - current character set */

extern int littleEndian(void);

extern char *baseNameStart(char *fullPathName);

#endif                          /* -- sysdep.h -- */

==> gargoyle-free_2023.1+dfsg.orig.tar.xz: garglk-2023.1/terps/alan3/sysdep.h <==
/*----------------------------------------------------------------------*\

  sysdep.h

  System dependencies file for Alan Adventure Language system

  N.B. The test for symbols used here should really be of three types
  - processor name (like PC, x86, ...)
  - os name (WIN32, Cygwin, MSYS2...)
  - compiler name and version (DJGPP, CYGWIN, GCC271, THINK-C, ...)

\*----------------------------------------------------------------------*/
#ifndef _SYSDEP_H_
#define _SYSDEP_H_

#include <stdbool.h>

/* Place definitions of OS and compiler here if necessary */

/* For command line editing in "pure" (non-Glk, non-Gargoyle)
 * interpreters, we need termio, assume it's available */
#define HAVE_TERMIOS

#ifdef __MINGW32__
#define __windows__
#undef HAVE_TERMIOS
#endif

#ifdef HAVE_WINGLK
#define HAVE_GLK
#endif

#ifdef HAVE_GARGLK
#define HAVE_GLK
#endif


/*----------------------------------------------------------------------

  Below follows OS and compiler dependent settings. They should not be
  changed except for introducing new sections when porting to new
  environments.

 */

/************/
/* Includes */
/************/

#include <stdio.h>
#include <ctype.h>
#include <unistd.h>


#ifdef __STDC__
#include <stdlib.h>
#include <string.h>
#endif


/***********************/
/* ISO character sets? */
/***********************/

/* Common case first */
#define ISO 1
#define NATIVECHARSET 0

#ifdef HAVE_GLK
#undef ISO
#define ISO 1
#undef NATIVECHARSET
#define NATIVECHARSET 0
#else	/* Glk is ISO, no matter what the OS */

#ifdef __win__
#undef ISO
#define ISO 1
#undef NATIVECHARSET
#define NATIVECHARSET 2
#endif

#endif

/**************************/
/* Strings for file modes */
/**************************/
#define READ_MODE "rb"
#define WRITE_MODE "wb"


/****************/
/* Have termio? */
/****************/

#ifdef HAVE_GLK
#  undef HAVE_TERMIOS   /* don't need TERMIO */
#else
#  ifdef __CYGWIN__
#    define HAVE_TERMIOS
#  endif
#  ifdef __unix__
#    define HAVE_TERMIOS
#  endif
#endif

/*******************************/
/* Is ANSI control available? */
/*******************************/

#ifdef HAVE_GLK
#  undef HAVE_ANSI_CONTROL /* don't need ANSI */
#else
#  ifdef __CYGWIN__
#    define HAVE_ANSI_CONTROL
#  endif
#endif

/******************************/
/* Use the READLINE function? */
/******************************/
#define USE_READLINE
#ifdef SOME_PLATFORM_WHICH_CANT_USE_READLINE
#  undef USE_READLINE
#endif


/* Internal character functions */
extern int isSpace(unsigned int c);      /* IN - Internal character to test */
extern int isLower(unsigned int c);      /* IN - Internal character to test */
extern int isUpper(unsigned int c);      /* IN - Internal character to test */
extern int isLetter(unsigned int c);     /* IN - Internal character to test */
extern int toLower(unsigned int c);      /* IN - Internal character to convert */
extern int toUpper(unsigned int c);      /* IN - Internal character to convert */
extern void stringToLowerCase(char str[]); /* INOUT - Internal string to convert */

extern bool equalStrings(char str1[], char str2[]); /* Case-insensitive compare */

extern int littleEndian(void);

extern char *baseNameStart(char *fullPathName);

#endif
